Ivy ORM allows you to write data access instructions that are then converted to the database you are working with.

By providing a schema file to the Datasource class, you are able to (hopefully) quickly write some code that allows you to query a database

# Current status
This is a very 'alpha' build. I've only done the very basics such as create and drop tables, and CRUD operations.
There is also only one connector - Postgres!